==> speech-analytic-testing_0.11.0_database.tar.gz: database/mssql/procedures/SaveUser.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveUser] (
	@VCC Varchar(50) = NULL, 					@ID Varchar(50) = NULL, 				@Email Varchar(50) = NULL,
	@Firstname Varchar(50) = NULL, 				@Lastname Varchar(50) = NULL, 			@Password Varchar(50) = NULL,
	@Role Varchar(50) = NULL, 					@Country Varchar(50) = NULL, 			@Language Varchar(50) = NULL,
	@TimeZone Varchar(50) = NULL,				@Preferences Varchar(200) = NULL, 		@IsSystemUser Bit = NULL,
	@LimitClients Bit = NULL,					@CreatedDate Datetime = NULL,			@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,			@LastModifiedByUserId Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	UPDATE [User]
	SET [Email] = @Email,
		[Firstname] = @Firstname,
		[Lastname] = @Lastname,
		[Password] = CASE WHEN @Password IS NULL OR @Password = '' THEN [Password] ELSE @Password END,
		[Role] = @Role,
		[Country] = @Country,
		[Language] = @Language,
		[TimeZone] = @TimeZone,
		[Preferences] = @Preferences,
		[IsSystemUser] = @IsSystemUser,
		[LimitClients] = @LimitClients,
		[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
		[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[TimeStamp] = GETUTCDATE()
	WHERE [VCC] = @VCC
	AND [ID] = @ID
    
    IF @@ROWCOUNT = 0
		INSERT INTO [User] (
			[VCC], [ID], [Email],
			[Firstname], [Lastname], [Password],
			[Role], [Country], [Language],
			[TimeZone], [Preferences], [IsSystemUser],
			[LimitClients], [CreatedDate], [CreatedByUserId],
			[LastModifiedDate], [LastModifiedByUserId],
			[TimeStamp]
			)
		VALUES (
			@VCC, @ID, @Email,
			@Firstname, @Lastname, @Password,
			@Role, @Country, @Language,
			@TimeZone, @Preferences, @IsSystemUser,
			@LimitClients, @CreatedDate, @CreatedByUserId,
			@LastModifiedDate, @LastModifiedByUserId,
			GETUTCDATE()
		)
		
    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_2.1.1_database.tar.gz: database/mssql/procedures/SaveUser.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveUser] (
	@VCC Varchar(50) = NULL, 					@ID Varchar(50) = NULL, 				@Email Varchar(50) = NULL,
	@Firstname Varchar(50) = NULL, 				@Lastname Varchar(50) = NULL, 			@Password Varchar(50) = NULL,
	@Role Varchar(50) = NULL, 					@Country Varchar(50) = NULL, 			@Language Varchar(50) = NULL,
	@TimeZone Varchar(50) = NULL,				@Preferences Varchar(200) = NULL, 		@IsSystemUser Bit = NULL,
	@IsExternalSupervisor BIT = 0,				@IsExternalAgent BIT =0,				@LimitClients Bit = NULL,					
	@CreatedDate Datetime = NULL,				@CreatedByUserId Varchar(50) = NULL,	@LastModifiedDate Datetime = NULL,			
	@LastModifiedByUserId Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	UPDATE [User]
	SET [Email] = @Email,
		[Firstname] = @Firstname,
		[Lastname] = @Lastname,
		[Password] = CASE WHEN @Password IS NULL OR @Password = '' THEN [Password] ELSE @Password END,
		[Role] = @Role,
		[Country] = @Country,
		[Language] = @Language,
		[TimeZone] = @TimeZone,
		[Preferences] = @Preferences,
		[IsSystemUser] = @IsSystemUser,
		[IsExternalSupervisor] = @IsExternalSupervisor,
		[IsExternalAgent] = @IsExternalAgent,
		[LimitClients] = @LimitClients,
		[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
		[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[TimeStamp] = GETUTCDATE()
	WHERE [VCC] = @VCC
	AND [ID] = @ID
    
    IF @@ROWCOUNT = 0
		INSERT INTO [User] (
			[VCC], [ID], [Email],
			[Firstname], [Lastname], [Password],
			[Role], [Country], [Language],
			[TimeZone], [Preferences], [IsSystemUser],
			[IsExternalSupervisor], [IsExternalAgent], [LimitClients], 
			[CreatedDate], [CreatedByUserId],
			[LastModifiedDate], [LastModifiedByUserId],
			[TimeStamp]
			)
		VALUES (
			@VCC, @ID, @Email,
			@Firstname, @Lastname, @Password,
			@Role, @Country, @Language,
			@TimeZone, @Preferences, @IsSystemUser,
			@IsExternalSupervisor, @IsExternalAgent, @LimitClients, 
			@CreatedDate, @CreatedByUserId,
			@LastModifiedDate, @LastModifiedByUserId,
			GETUTCDATE()
		)
		
    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
